class CaseFoldDict(dict):

    def __getitem__(self, item):
        return dict.__getitem__(self, item.casefold())

    def __setitem__(self, key, value):
        dict.__setitem__(self, key.casefold(), value)

    # noinspection PyMethodOverriding
    def setdefault(self, key, default):
        return dict.setdefault(self, key.casefold(), default)

    def get(self, key, default=None):
        return self.get(key.casefold(), default)



from mvcbotbase.classes_for_command_arguments import (
    BaseArg, IntArg, WordArg, StringArg, Sequence
)
from mvcbotbase.message_classes import (
    AbstractIncomingMessage, OutgoingMessage, AttachmentType,
    AbstractIncomingAttachment, OutgoingFileAttachment, Attachment,
    ContentCantBeDownloadedError, UndownloadableAttachment,
    AttachmentToUploadHasUnknownFileTypeError, OutgoingAttachment
)
from mvcbotbase.mvcbotbase import MVCBotBase
from mvcbotbase.social_network_provider import SocialNetworkProvider
from mvcbotbase import social_network_provider_implementations, command_info

__all__ = [
    "MVCBotBase",
    "SocialNetworkProvider", "social_network_provider", "BaseArg", "IntArg",
    "mvcbotbase", "WordArg", "StringArg", "Sequence", "AttachmentType",
    "OutgoingMessage", "OutgoingAttachment", "OutgoingFileAttachment",
    "Attachment", "UndownloadableAttachment", "AbstractIncomingAttachment",
    "AbstractIncomingMessage", "message_classes",
    "AttachmentToUploadHasUnknownFileTypeError", "ContentCantBeDownloadedError",
    "classes_for_command_arguments", "command_info",
    "social_network_provider_implementations"
]
